@@ -39,9 +39,17 @@
 void
 cpu_init_f (void)
 {
-	if (get_cpu_type() == CPU_7450) {
+	switch (get_cpu_type()) {
+	case CPU_7450:
+	case CPU_7455:
+	case CPU_7457:
+	case CPU_7448:
 		/* enable the timebase bit in HID0 */
 		set_hid0(get_hid0() | 0x4000000);
+		break;
+	default:
+		/* do nothing */
+		break;
 	}
 }
 
